@echo off

rem /******************************************************************
rem  *                                                                *
rem  *      DVBTENCO2 - An ETSI DVB-T standard encoder/modulator.     *
rem  *                  This is the second version of the modulator   *
rem  *                  built upon the dvblib library                 *
rem  *                                                                *
rem  *    This encoder/modulator follows the specifications of the    *
rem  *    standard ETSI EN 300 744 V1.5.1 (2004-11).                  *
rem  *                                                                *
rem  *    Author: Giuseppe Baruffa (baruffa@diei.unipg.it)            *
rem  *    Website: http://dante.diei.unipg.it/dvbt                    *
rem  *                                                                *
rem  *                   Copyright 2000-2005                          *
rem  *                                                                *
rem  ******************************************************************/

rem	Batch test file for the dvbtenco program

rem Setting variables

set ENCO=.\dvbtenco
set TESTFILE=.\test_long.m2v
set MP2GEN=.\mpeg2gen
set TSTLEN=1200000
set SPEEDFILE=test_windows20.txt
set TEMPFILE=temporary_dvbtenco_file.txt
set CHECKWPP=.\wppcheck
set CLOCKMHZ=2800

set MODES=2k 8k
set CONST=4 16 64
set ALPHA=NH
set DELTA=1/32 1/16 1/8 1/4
set RATES=1/2 2/3 3/4 5/6 7/8

echo. 
echo Speed test for %ENCO%
echo.

if not exist %TESTFILE% (
	echo Creating test file
	%MP2GEN% %TSTLEN% 2 %TESTFILE%
)

if exist %SPEEDFILE% del %SPEEDFILE%

for %%m in (%MODES%) do (
	for %%M in (%CONST%) do (
		for %%a in (%ALPHA%) do (
			for %%d in (%DELTA%) do (
				for %%r in (%RATES%) do (
					echo %%m %%M %%a %%d %%r
					%ENCO% -i %TESTFILE% -m %%m -M %%M -a %%a -D %%d -p %%r -v 1 > %TEMPFILE%
					type %TEMPFILE%
					type %TEMPFILE% >> %SPEEDFILE%
				)
			)
		)
	)
)

if exist %TEMPFILE% del %TEMPFILE%

echo Test done

%CHECKWPP% %SPEEDFILE% %CLOCKMHZ%

